@@ -420,10 +420,8 @@ class SoozAccess(object):
             )
         except HTTPError as e:
             pass
-        else:
-            content = json.loads(r.content.decode("utf-8"))
         finally:
-            self.show_status("    Insert Response", r)
+            self.show_status("    Put Response", r)
 
         return content, r
 
